==> qore-0.9.3.tar.bz2: qore-0.9.3/docs/modules/SalesforceRestClient/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SalesforceRestClient Module Reference", "index.html", [
    [ "SalesforceRestClient Module", "index.html", [
      [ "SalesforceRestClient Introduction", "index.html#salesforcerestclientintro", null ],
      [ "Release Notes", "index.html#salesforcerestclientrelnotes", [
        [ "SalesforceRestClient v1.3", "index.html#salesforcerestclientv1_3", null ],
        [ "SalesforceRestClient v1.2", "index.html#salesforcerestclientv1_2", null ],
        [ "SalesforceRestClient v1.1.1", "index.html#salesforcerestclientv1_1_1", null ],
        [ "SalesforceRestClient v1.1", "index.html#salesforcerestclientv1_1", null ],
        [ "SalesforceRestClient v1.0", "index.html#salesforcerestclientv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__astparser__symbol__usage__kind__constants.html#ga14aaa0ce0a0394b49559e6aefaa028d5",
"group__date__and__time__functions.html#ga92ef075d0aa1945a11580a864bc7f4cb",
"group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba",
"group__math__functions.html",
"group__option__constants.html",
"group__sql__cops.html#ga0bbff735e271b62495539bbc466e7145",
"group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.3.1.tar.bz2: qore-0.9.3.1/docs/modules/SalesforceRestClient/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SalesforceRestClient Module Reference", "index.html", [
    [ "SalesforceRestClient Module", "index.html", [
      [ "SalesforceRestClient Introduction", "index.html#salesforcerestclientintro", null ],
      [ "Release Notes", "index.html#salesforcerestclientrelnotes", [
        [ "SalesforceRestClient v1.3", "index.html#salesforcerestclientv1_3", null ],
        [ "SalesforceRestClient v1.2", "index.html#salesforcerestclientv1_2", null ],
        [ "SalesforceRestClient v1.1.1", "index.html#salesforcerestclientv1_1_1", null ],
        [ "SalesforceRestClient v1.1", "index.html#salesforcerestclientv1_1", null ],
        [ "SalesforceRestClient v1.0", "index.html#salesforcerestclientv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__astparser__symbol__usage__kind__constants.html#ga14aaa0ce0a0394b49559e6aefaa028d5",
"group__date__and__time__functions.html#ga92ef075d0aa1945a11580a864bc7f4cb",
"group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba",
"group__list__functions.html#gad9e205ca0a43f52a1388611b54521c19",
"group__old__dbi__functions.html#gaba3a2421c3d2b492c9494f346c13da1c",
"group__sql__cop__trunc__date__enum.html#ga7b5441c9b39b31615e264fa837ba78db",
"group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97",
"modules.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
